#include <shogun/base/init.h>
#include <shogun/base/some.h>
#include <shogun/classifier/svm/LibLinear.h>
#include <shogun/classifier/svm/LibLinear.h>
#include <shogun/evaluation/ContingencyTableEvaluation.h>
#include <shogun/features/DenseFeatures.h>
#include <shogun/io/CSVFile.h>
#include <shogun/labels/BinaryLabels.h>
#include <shogun/lib/SGVector.h>

using namespace shogun;

int main(int, char*[])
{
init_shogun_with_defaults();

auto f_feats_train = some<CCSVFile>("../../data/classifier_binary_2d_linear_features_train.dat");
auto f_feats_test = some<CCSVFile>("../../data/classifier_binary_2d_linear_features_test.dat");
auto f_labels_train = some<CCSVFile>("../../data/classifier_binary_2d_linear_labels_train.dat");
auto f_labels_test = some<CCSVFile>("../../data/classifier_binary_2d_linear_labels_test.dat");

//![create_features]
auto features_train = some<CDenseFeatures<float64_t>>(f_feats_train);
auto features_test = some<CDenseFeatures<float64_t>>(f_feats_test);
auto labels_train = some<CBinaryLabels>(f_labels_train);
auto labels_test = some<CBinaryLabels>(f_labels_test);
//![create_features]

//![set_parameters]
auto C = 1.0;
auto epsilon = 0.001;
//![set_parameters]

//![create_instance]
auto svm = some<CLibLinear>(C, features_train, labels_train);
svm->set_liblinear_solver_type(LIBLINEAR_SOLVER_TYPE::L2R_L2LOSS_SVC);
svm->set_epsilon(epsilon);
//![create_instance]

//![train_and_apply]
svm->train();
auto labels_predict = svm->apply_binary(features_test);
//![train_and_apply]

//![extract_weights_bias]
auto w = svm->get_w();
auto b = svm->get_bias();
//![extract_weights_bias]

//![evaluate_accuracy]
auto eval = some<CAccuracyMeasure>();
auto accuracy = eval->evaluate(labels_predict, labels_test);
//![evaluate_accuracy]

// additional integration testing variables
auto output = labels_predict->get_labels();

exit_shogun();
return 0;
}
