#include <shogun/base/init.h>
#include <shogun/base/some.h>
#include <shogun/clustering/KMeans.h>
#include <shogun/clustering/KMeansMiniBatch.h>
#include <shogun/distance/EuclideanDistance.h>
#include <shogun/features/DenseFeatures.h>
#include <shogun/io/CSVFile.h>
#include <shogun/lib/SGMatrix.h>
#include <shogun/lib/SGVector.h>
#include <shogun/mathematics/Math.h>

using namespace shogun;

int main(int, char*[])
{
init_shogun_with_defaults();

auto f_feats_train = some<CCSVFile>("../../data/classifier_binary_2d_linear_features_train.dat");
CMath::init_random(1);

//![create_features]
auto features_train = some<CDenseFeatures<float64_t>>(f_feats_train);
//![create_features]

//![choose_distance]
auto distance = some<CEuclideanDistance>(features_train, features_train);
//![choose_distance]

//![create_instance_lloyd]
auto kmeans = some<CKMeans>(2, distance);
//![create_instance_lloyd]

//![train_dataset]
kmeans->train();
//![train_dataset]

//![extract_centers_and_radius]
auto c = kmeans->get_cluster_centers();
auto r = kmeans->get_radiuses();
//![extract_centers_and_radius]

//![create_instance_mb]
auto kmeans_mb = some<CKMeansMiniBatch>(2, distance);
kmeans_mb->set_mb_params(4, 1000);
//![create_instance_mb]

exit_shogun();
return 0;
}
