#include <shogun/base/init.h>
#include <shogun/base/some.h>
#include <shogun/converter/ica/FastICA.h>
#include <shogun/features/DenseFeatures.h>
#include <shogun/features/Features.h>
#include <shogun/io/CSVFile.h>
#include <shogun/lib/SGMatrix.h>
#include <shogun/mathematics/Math.h>

using namespace shogun;

int main(int, char*[])
{
init_shogun_with_defaults();

auto f_feats = some<CCSVFile>("../../data/ica_2_sources.dat");

CMath::init_random(1);

//![create_features]
auto features = some<CDenseFeatures<float64_t>>(f_feats);
//![create_features]

//![set_parameters]
auto ica = some<CFastICA>();
ica->set_max_iter(200);
ica->set_tol(0.00001);
//![set_parameters]

//![apply_convert]
auto converted = ica->apply(features);
//![apply_convert]

//![extract]
auto mixing_matrix = ica->get_mixing_matrix();
auto casted = CDenseFeatures<float64_t>::obtain_from_generic(converted);
auto unmixed_signal = casted->get_feature_matrix();
//![extract]


exit_shogun();
return 0;
}
