#include <shogun/base/init.h>
#include <shogun/base/some.h>
#include <shogun/distance/EuclideanDistance.h>
#include <shogun/features/DenseFeatures.h>
#include <shogun/io/CSVFile.h>
#include <shogun/lib/SGMatrix.h>

using namespace shogun;

int main(int, char*[])
{
init_shogun_with_defaults();

auto f_feats_a = some<CCSVFile>("../../data/fm_train_real.dat");
auto f_feats_b = some<CCSVFile>("../../data/fm_test_real.dat");

//![create_features]
auto features_a = some<CDenseFeatures<float64_t>>(f_feats_a);
auto features_b = some<CDenseFeatures<float64_t>>(f_feats_b);
//![create_features]

//![create_instance]
auto distance = some<CEuclideanDistance>(features_a, features_a);
//![create_instance]

//![extract_distance]
auto distance_matrix_aa = distance->get_distance_matrix();
//![extract_distance]

//![refresh_distance]
distance->init(features_a, features_b);
//![refresh_distance]

//![extract_sq_distance]
distance->set_disable_sqrt(true);
auto distance_matrix_ab = distance->get_distance_matrix();
//![extract_sq_distance]

exit_shogun();
return 0;
}
