#include <shogun/base/init.h>
#include <shogun/base/some.h>
#include <shogun/classifier/mkl/MKLClassification.h>
#include <shogun/classifier/svm/LibSVM.h>
#include <shogun/evaluation/ContingencyTableEvaluation.h>
#include <shogun/evaluation/CrossValidation.h>
#include <shogun/evaluation/CrossValidation.h>
#include <shogun/evaluation/CrossValidationStorage.h>
#include <shogun/evaluation/CrossValidationStorage.h>
#include <shogun/evaluation/StratifiedCrossValidationSplitting.h>
#include <shogun/features/CombinedFeatures.h>
#include <shogun/features/DenseFeatures.h>
#include <shogun/io/CSVFile.h>
#include <shogun/kernel/CombinedKernel.h>
#include <shogun/kernel/GaussianKernel.h>
#include <shogun/labels/BinaryLabels.h>
#include <shogun/lib/SGVector.h>
#include <shogun/lib/parameter_observers/ParameterObserverCV.h>

using namespace shogun;

int main(int, char*[])
{
init_shogun_with_defaults();

auto f_feats = some<CCSVFile>("../../data/fm_train_real.dat");
auto f_labels = some<CCSVFile>("../../data/label_train_twoclass.dat");

//![create_features]
auto features = some<CDenseFeatures<float64_t>>(f_feats);
auto combined_features = some<CCombinedFeatures>();
combined_features->append_feature_obj(features);
combined_features->append_feature_obj(features);
combined_features->append_feature_obj(features);
auto labels = some<CBinaryLabels>(f_labels);
//![create_features]

//![create_kernels]
auto kernel = some<CCombinedKernel>();
auto k_1 = some<CGaussianKernel>(10, 0.1);
auto k_2 = some<CGaussianKernel>(10, 1);
auto k_3 = some<CGaussianKernel>(10, 2);
kernel->append_kernel(k_1);
kernel->append_kernel(k_2);
kernel->append_kernel(k_3);
//![create_kernels]

//![create_classifier]
auto libsvm = some<CLibSVM>();
auto svm = some<CMKLClassification>(libsvm);
svm->set_interleaved_optimization_enabled(false);
svm->set_kernel(kernel);
//![create_classifier]

//![create_cross_validation]
auto splitting_strategy = some<CStratifiedCrossValidationSplitting>(labels, 5);
auto evaluation_criterium = some<CAccuracyMeasure>();
auto cross = some<CCrossValidation>(svm, combined_features, labels, splitting_strategy, evaluation_criterium);
cross->set_autolock(false);
cross->set_num_runs(2);
//![create_cross_validation]

//![create_observer]
auto mkl_obs = some<CParameterObserverCV>(true);
cross->subscribe_to_parameters(mkl_obs);
//[!create_observer]

//![evaluate_and_get_result]
auto result = some<CCrossValidationResult>();
result = CCrossValidationResult::obtain_from_generic(cross->evaluate());
//![evaluate_and_get_result]

//![get_results]
auto mean = result->get_mean();
auto stddev = result->get_std_dev();
//![get_results]

//![get_fold_machine]
auto obs = mkl_obs->get_observation(0);
auto fold = obs->get_fold(0);
auto machine = CMKLClassification::obtain_from_generic(fold->get_trained_machine());
//![get_fold_machine]

//![get_weights]
auto k = CCombinedKernel::obtain_from_generic(machine->get_kernel());
auto w = k->get_subkernel_weights();
//![get_weights]

exit_shogun();
return 0;
}
